@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2019-06-20'; # DATE
-our $VERSION = '0.842'; # VERSION
+our $DATE = '2019-06-26'; # DATE
+our $VERSION = '0.843'; # VERSION
 
 use 5.010001;
 use strict;
@@ -227,12 +227,24 @@ sub _opt2ospec {
         my $ishos = $ishos[$i];
 
         if ($type eq 'bool') {
-            if (length($opt) == 1 || $cset->{is}) {
+            if (length $opt == 1) {
                 # single-letter option like -b doesn't get --nob.
-                # [bool=>{is=>1}] also means it's a flag and should not get
+                push @res, ($opt, {opts=>[$opt]}), undef;
+            } elsif ($cset->{is} || $cset->{is_true}) {
+                # an always-true bool ('true' or [bool => {is=>1}] or
+                # [bool=>{is_true=>1}] also means it's a flag and should not get
                 # --nofoo.
                 push @res, ($opt, {opts=>[$opt]}), undef;
+            } elsif ((defined $cset->{is} && !$cset->{is}) ||
+                         (defined $cset->{is_true} && !$cset->{is_true})) {
+                # an always-false bool ('false' or [bool => {is=>0}] or
+                # [bool=>{is_true=>0}] also means it's a flag and should only be
+                # getting --nofoo.
+                for (negations_for_option($opt)) {
+                    push @res, $_, {opts=>[$_]}, {is_neg=>1, pos_opts=>[$opt]};
+                }
             } else {
+                # a regular bool gets --foo as well as --nofoo
                 my @negs = negations_for_option($opt);
                 push @res, $opt, {opts=>[$opt]}, {is_neg=>0, neg_opts=>\@negs};
                 for (@negs) {
@@ -1124,7 +1136,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.842 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2019-06-20.
+This document describes version 0.843 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2019-06-26.
 
 =head1 SYNOPSIS
 
